==> yylivesdk4cloud-audiovideo-2.2.14-sources.jar: com/yy/yylivesdk4cloud/ThunderRtcVideoEngine.java <==
package com.yy.yylivesdk4cloud;

public class ThunderRtcVideoEngine {

    private static boolean mIsInited = false;
    private Boolean bUse32bitUid = false;
    private Boolean enableLocalVideo = false;
    private ThunderVideoEncoderConfiguration config;
    private int playType;
    private int resolutionMode;

    private ThunderPreviewView mThunderPreviewView = null;
    private ThunderPlayerView mThunderPlayerView = null;

    private ThunderRtcVideoEngine(){

    }

    private static class SingleonHolder{
        private static final ThunderRtcVideoEngine INSTANCE = new ThunderRtcVideoEngine();
    }

    public static ThunderRtcVideoEngine sharedInstance() {
        return ThunderRtcVideoEngine.SingleonHolder.INSTANCE;
    }

    public int enableVideo() {
        return 0;
    }

    public int disableVideo() {
        return 0;
    }

    public int enableLocalVideo(Boolean enabled) {
        if(enabled) {
            ThunderAPI.sharedInstance().getPublishRoom().startCapture();
        }else {
            ThunderAPI.sharedInstance().getPublishRoom().stopCapture();
        }
        return 0;
    }

    public int muteAllRemoteVideoStreams(Boolean mute) {
        return 0;
    }

    public int muteLocalVideoStream(Boolean mute) {
        if(mute) {
            ThunderAPI.sharedInstance().getPublishRoom().stopSinglePublish();
        }else {
            ThunderAPI.sharedInstance().getPublishRoom().startSinglePublish(playType,resolutionMode);
        }
        return 0;
    }

    public int muteRemoteVideoStream(String uid, Boolean mute) {
        return 0;
    }

    public int setDefaultMuteAllRemoteVideoStreams(Boolean mute) {
        return 0;
    }

    int setLocalRenderMode(int mode) {
        ThunderAPI.sharedInstance().setPreviewRenderMode(mode);
        return 0;
    }

    int setRemoteRenderMode(String uid, int mode) {
        return 0;
    }

    int setVideoEncoderConfiguration(int pType,int mode) {
        playType = pType;
        resolutionMode = mode;
        return 0;
    }

    int setupLocalVideo(ThunderVideoCanvas localView) {
        mThunderPreviewView = (ThunderPreviewView) localView.mView;
        return 0;
    }

    int setupRemoteVideo(ThunderVideoCanvas remoteView){

        // Todo

//        ThunderStream stream = new ThunderStream();
//        stream.streamName = "";
//        stream.appId = 0;
//        stream.speakerUid = 0;
//        stream.bVideo = false;
//        stream.toView = null;
//        stream.scaleMode = ThunderConstant.ThunderVideoViewScaleMode.THUNDERVIDEOVIEW_SCALE_MODE_FILL;
//        stream.lineSeq = 0;
//        if(bUse32bitUid) {
//            try {
//                stream.speakerUid = Long.parseLong(remoteView.mUid);
//            } catch (NumberFormatException exception) {
//                return -1;
//            }
//        }else {
//
//            try {
//                stream.speakerUid = Integer.parseInt(remoteView.mUid);
//            }
//            catch (Exception e) {
//                stream.speakerUid = 0;
//            }
//
//            if(0 == stream.speakerUid){
//                return -3;
//            }
//        }

//        ThunderAPI.sharedInstance().getPlayer().

        return 0;
    }

    int startVideoPreview() {
        // Todo: Need media library to add interface
        ThunderAPI.sharedInstance().getPublishRoom().startVideoPreview(mThunderPreviewView,playType,resolutionMode);
        return 0;
    }

    int stopVideoPreview() {
        // Todo: Need media library to add interface
        ThunderAPI.sharedInstance().getPublishRoom().stopVideoPreview();
        return 0;
    }
}

==> yylivesdk4cloud-audiovideo-2.3.1-sources.jar: com/yy/yylivesdk4cloud/ThunderRtcVideoEngine.java <==
package com.yy.yylivesdk4cloud;

public class ThunderRtcVideoEngine {

    private static boolean mIsInited = false;
    private Boolean bUse32bitUid = false;
    private Boolean enableLocalVideo = false;
    private ThunderVideoEncoderConfiguration config;
    private int playType;
    private int resolutionMode;

    private ThunderPreviewView mThunderPreviewView = null;
    private ThunderPlayerView mThunderPlayerView = null;

    private ThunderRtcVideoEngine(){

    }

    private static class SingleonHolder{
        private static final ThunderRtcVideoEngine INSTANCE = new ThunderRtcVideoEngine();
    }

    public static ThunderRtcVideoEngine sharedInstance() {
        return ThunderRtcVideoEngine.SingleonHolder.INSTANCE;
    }

    public int enableVideo() {
        return 0;
    }

    public int disableVideo() {
        return 0;
    }

    public int enableLocalVideo(Boolean enabled) {
        if(enabled) {
            ThunderAPI.sharedInstance().getPublishRoom().startCapture();
        }else {
            ThunderAPI.sharedInstance().getPublishRoom().stopCapture();
        }
        return 0;
    }

    public int muteAllRemoteVideoStreams(Boolean mute) {
        return 0;
    }

    public int muteLocalVideoStream(Boolean mute) {
        if(mute) {
            ThunderAPI.sharedInstance().getPublishRoom().stopSinglePublish();
        }else {
            ThunderAPI.sharedInstance().getPublishRoom().startSinglePublish(playType,resolutionMode);
        }
        return 0;
    }

    public int muteRemoteVideoStream(String uid, Boolean mute) {
        return 0;
    }

    public int setDefaultMuteAllRemoteVideoStreams(Boolean mute) {
        return 0;
    }

    int setLocalRenderMode(int mode) {
        ThunderAPI.sharedInstance().setPreviewRenderMode(mode);
        return 0;
    }

    int setRemoteRenderMode(String uid, int mode) {
        return 0;
    }

    int setVideoEncoderConfiguration(int pType,int mode) {
        playType = pType;
        resolutionMode = mode;
        return 0;
    }

    int setupLocalVideo(ThunderVideoCanvas localView) {
        mThunderPreviewView = (ThunderPreviewView) localView.mView;
        return 0;
    }

    int setupRemoteVideo(ThunderVideoCanvas remoteView){

        // Todo

//        ThunderStream stream = new ThunderStream();
//        stream.streamName = "";
//        stream.appId = 0;
//        stream.speakerUid = 0;
//        stream.bVideo = false;
//        stream.toView = null;
//        stream.scaleMode = ThunderConstant.ThunderVideoViewScaleMode.THUNDERVIDEOVIEW_SCALE_MODE_FILL;
//        stream.lineSeq = 0;
//        if(bUse32bitUid) {
//            try {
//                stream.speakerUid = Long.parseLong(remoteView.mUid);
//            } catch (NumberFormatException exception) {
//                return -1;
//            }
//        }else {
//
//            try {
//                stream.speakerUid = Integer.parseInt(remoteView.mUid);
//            }
//            catch (Exception e) {
//                stream.speakerUid = 0;
//            }
//
//            if(0 == stream.speakerUid){
//                return -3;
//            }
//        }

//        ThunderAPI.sharedInstance().getPlayer().

        return 0;
    }

    int startVideoPreview() {
        // Todo: Need media library to add interface
        ThunderAPI.sharedInstance().getPublishRoom().startVideoPreview(playType,resolutionMode);
        return 0;
    }

    int stopVideoPreview() {
        // Todo: Need media library to add interface
        ThunderAPI.sharedInstance().getPublishRoom().stopVideoPreview();
        return 0;
    }
}
